==> kmuddy-0.7.1.tar.gz: kmuddy-0.7.1/kmuddy/ctranscript.h <==
/***************************************************************************
                          ctranscript.h  -  session transcript
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ct oct 31 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.org
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTRANSCRIPT_H
#define CTRANSCRIPT_H

/*
Current status of cTranscript class (Nov 1, 2002):
 - requested functionality implemented
 - new features may still be added
 - code has been tested and it seems to work
*/

#include <stdio.h>

#include <qobject.h>

#include "csessionbase.h"

class cTextChunk;
class dlgTranscript;
class dlgDumpBuffer;

/**
This class handles session transcript feature.
  *@author Tomas Mecir
  */

class cTranscript : public QObject, public cSessionBase {
   Q_OBJECT
private:
  QString directory, name;
public: 
  cTranscript ();
  ~cTranscript ();
  
  void load();
  void save();
  
public slots:
  void addLineToTranscript (cTextChunk *chunk);
  void addLineToAdvTranscript (cTextChunk *chunk);
  
  void addCommandToTranscript (const QString &what);
  void addScriptOutputToTranscript (const QString &what);
  void stopTranscript ();
  void stopAdvTranscript ();
  void startAdvTranscript ();
  void setEnableRotate (bool val) { rotatedaily = val; };
  bool enableRotate () { return rotatedaily; };
  void setPrependTimestamp (bool val) { includetimestamp = val; };
  bool prependTimestamp () { return includetimestamp; };
  void configure ();
  void dumpBuffer ();
  void timeout ();
protected slots:
  void applyTranscript ();
  void doDumpBuffer ();
protected:
  void startTranscript ();
  
  void setAFName (const QString &what);
  QString getAFName ();

  bool running, advrunning, rotatedaily;
  bool overwrite, includedump;
  bool includetimestamp;
  FILE *file, *advfile;
  QString fname, advfname, fileformat;
  QTimer *transtimer;

  //type of normal and advanced transcript
  char type, advtype;
  
  dlgTranscript *tdlg;
  dlgDumpBuffer *bdlg;
};

#endif

==> kmuddy-0.8.tar.gz: kmuddy-0.8/kmuddy/ctranscript.h <==
/***************************************************************************
                          ctranscript.h  -  session transcript
    This file is a part of KMuddy distribution.
                             -------------------
    begin                : Ct oct 31 2002
    copyright            : (C) 2002 by Tomas Mecir
    email                : kmuddy@kmuddy.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef CTRANSCRIPT_H
#define CTRANSCRIPT_H

#include <stdio.h>

#include <qobject.h>

#include "cactionbase.h"

class dlgTranscript;
class dlgDumpBuffer;

/**
This class handles session transcript feature.
  *@author Tomas Mecir
  */

class cTranscript : public QObject, public cActionBase {
   Q_OBJECT
private:
  QString directory, name;
public: 
  cTranscript (int sess);
  ~cTranscript ();
  
  void load();
  void save();
  
  void addLineToTranscript (cTextChunk *chunk);
  void addLineToAdvTranscript (cTextChunk *chunk);
  
  void stopTranscript ();
  void stopAdvTranscript ();
  void startAdvTranscript ();
  void setEnableRotate (bool val) { rotatedaily = val; };
  bool enableRotate () { return rotatedaily; };
  void setPrependTimestamp (bool val) { includetimestamp = val; };
  bool prependTimestamp () { return includetimestamp; };
public slots:
  void configure ();
  void dumpBuffer ();
  void timeout ();
protected slots:
  void applyTranscript ();
  void doDumpBuffer ();
protected:
  virtual void eventHandler (QString event, int session);
  virtual void eventHandler (QString event, int session, cTextChunk *chunk);
  
  void startTranscript ();
  
  void setAFName (const QString &what);
  QString getAFName ();

  bool running, advrunning, rotatedaily;
  bool overwrite, includedump;
  bool includetimestamp;
  FILE *file, *advfile;
  QString fname, advfname, fileformat;
  QTimer *transtimer;

  //type of normal and advanced transcript
  char type, advtype;
  
  dlgTranscript *tdlg;
  dlgDumpBuffer *bdlg;
  
  bool nextLineGagged;
};

#endif
